@@ -1,7 +1,7 @@
 from datetime import datetime
 from typing import Callable, List, Optional, Union
 
-from pydantic import BaseModel, EmailStr, HttpUrl
+from pydantic import BaseModel, EmailStr, Field, HttpUrl
 
 
 class BaseEntity(BaseModel):
@@ -17,7 +17,7 @@ class Client(BaseEntity):
 
 class Group(BaseEntity):
     name: str
-    wid: int
+    wid: int = Field(alias="workspace_id")
 
 
 class Project(BaseEntity):
@@ -28,10 +28,10 @@ class Project(BaseEntity):
     is_private: bool = True
     template: Optional[bool] = None
     template_id: Optional[int] = None
-    billable: bool = True
+    billable: Optional[bool] = True
     auto_estimates: Optional[bool] = False
     estimated_hours: Optional[int] = None
-    color: Union[str, int] = None
+    color: Union[str, int] = 0
     rate: Optional[float] = None
     created_at: Optional[datetime] = None
 
@@ -48,15 +48,16 @@ class ProjectUser(BaseEntity):
 
 class Tag(BaseEntity):
     name: str
-    wid: int
+    wid: int = Field(alias="workspace_id")
 
 
 class Task(BaseEntity):
     name: str
-    pid: int
-    wid: int
-    uid: Optional[int] = None
+    pid: int = Field(alias="project_id")
+    wid: int = Field(alias="workspace_id")
+    uid: Optional[int] = Field(alias="user_id", default=None)
     estimated_seconds: Optional[int] = None
+    tracked_seconds: Optional[int] = None
     active: Optional[bool] = True
 
 
@@ -66,10 +67,10 @@ class TimeEntry(BaseEntity):
     tid: Optional[int] = None
     description: Optional[str] = None
     billable: Optional[bool] = False
-    start: Union[datetime, Callable] = datetime.now
-    stop: Union[datetime, Callable] = None
+    start: Union[datetime, Callable[[], datetime]] = datetime.now
+    stop: Optional[Union[datetime, Callable[[], datetime]]] = None
     duration: int
-    created_with: Optional[str]
+    created_with: Optional[str] = None
     tags: List[str] = []
     duronly: Optional[bool] = None
 
@@ -82,40 +83,18 @@ class ReportTimeEntry(BaseEntity):
     description: Optional[str] = None
     billable: Optional[int] = False
     is_billable: Optional[bool] = False
-    cur: Optional[str] = False
-    start: Union[datetime, Callable] = datetime.now
-    end: Union[datetime, Callable] = None
+    cur: Optional[Union[str, bool]] = False
+    start: Union[datetime, Callable[[], datetime]] = datetime.now
+    end: Optional[Union[datetime, Callable[[], datetime]]] = None
     dur: int
     tags: List[str] = []
 
 
-class User(BaseEntity):
-    api_token: Optional[str] = None
-    default_wid: Optional[int] = None
-    email: EmailStr
-    fullname: str
-    jquery_timeofday_format: str
-    jquery_date_format: str
-    timeofday_format: str
-    date_format: str
-    store_start_and_stop_time: bool
-    beginning_of_week: int = 0
-    language: str
-    image_url: HttpUrl
-    sidebar_piechart: bool
-    new_blog_post: dict
-    send_product_emails: bool
-    send_weekly_report: bool
-    send_timer_notifications: bool
-    openid_enabled: bool
-    timezone: str
-
-
 class Workspace(BaseEntity):
     name: str
     premium: bool
     admin: bool
-    default_hourly_rate: float
+    default_hourly_rate: Optional[float] = None
     default_currency: str
     only_admins_may_create_projects: bool
     only_admins_see_billable_rates: bool
@@ -124,6 +103,24 @@ class Workspace(BaseEntity):
     logo_url: Optional[HttpUrl] = None
 
 
+class User(BaseEntity):
+    api_token: Optional[str] = None
+    default_wid: Optional[int] = Field(alias="default_workspace_id", default=None)
+    email: EmailStr
+    fullname: str
+    beginning_of_week: int = 0
+    image_url: Optional[HttpUrl] = None
+    openid_enabled: Optional[bool] = None
+    timezone: Optional[str] = None
+    country_id: Optional[int] = None
+    projects: Optional[Project] = None
+    tags: Optional[Tag] = None
+    tasks: Optional[Task] = None
+    time_entries: Optional[TimeEntry] = None
+    updated_at: str
+    workspaces: Optional[Workspace] = None
+
+
 class WorkspaceUser(BaseEntity):
     uid: int
     wid: int
